import "./App.css";
import logo from "./logo.svg";
import randomPic from "./random.png";
import Color from "color";
import { useState, useRef } from "react";
import Sentiment from "sentiment";
const sentiment = new Sentiment();
const ourColor = Color("rgb(255, 255, 255)");

function Button(props) {
  return <button onClick={props.onClick}>{props.label}</button>;
}

function App() {
  const [color, setColor] = useState(ourColor);
  const [score, setScore] = useState(0);

  const inputRef = useRef();

  function lighten() {
    setColor(color.lighten(0.1));
  }

  function darken() {
    setColor(color.darken(0.1));
  }

  function random() {
    const randomRed = Math.random() * 255;
    const randomGreen = Math.random() * 255;
    const randomBlue = Math.random() * 255;

    const randomColor = Color.rgb(randomRed, randomGreen, randomBlue);
    setColor(randomColor);
  }

  function negate() {
    setColor(color.negate());
  }

  function handleSentiment() {
    const result = sentiment.analyze(inputRef.current.value);
    setScore(result.score);

    if (result.score < 0) {
      setColor(Color.rgb(255, 0, 0));
    }

    if (result.score > 0) {
      setColor(Color.rgb(0, 255, 0));
    }
  }

  return (
    <div className="App">
      <header className="App-header">
        <p>Type here some text to see your sentiment</p>
        <input
          ref={inputRef}
          onChange={handleSentiment}
          placeholder="Type things"
        ></input>
        <p>Your score {score}</p>

        <p>
          {score > 3 ? "Really good human" : ""}
          {score > 0 && score <= 3 ? "Good human" : ""}
          {score === 0 ? (
            <div>
              <img style={{ width: "100px" }} src={logo} alt="logo" />
              <p>Here some text</p>
            </div>
          ) : 
            ""
          }
          {score < 0 ? "Bad human" : ""}
        </p>
        <img
          style={{
            width: "100px",
            border: "1px solid black",
            margin: "1rem",
          }}
          src="https://static.npmjs.com/attachments/ck3uweazy72ye8874y9kkxnx1-gak.png"
          alt="logo"
        />

        {/* condition ? truthy : falsy */}
        <div
          style={{
            width: "100px",
            height: "100px",
            background: color.hex(),
          }}
        ></div>
        <Button onClick={lighten} label="Lighten" />
        <Button onClick={darken} label="Darken" />
        <Button onClick={random} label="Random" />
        <Button onClick={negate} label="Negate" />
      </header>
    </div>
  );
}

export default App;
